.. ui.cmdline.rst
.. 
.. Project: AutoArchive
.. License: GNU GPLv3
.. 
.. Copyright (C) 2003 - 2015 Róbert Čerňanský



.. A section for the AutoArchive._ui.cmdline package.



AutoArchive._ui._cmdline
========================

.. automodule:: AutoArchive._ui.cmdline
   :no-members:



Modules
-------

_user_action_executor
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._ui.cmdline._user_action_executor
.. autoclass:: UserActionExecutor



_cmdline_ui
^^^^^^^^^^^

.. automodule:: AutoArchive._ui.cmdline._cmdline_ui
.. autoclass:: CmdlineUi



_cmdline_commands
^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._ui.cmdline._cmdline_commands
.. autoclass:: CmdlineCommands
.. autoclass:: _CmdlineCommandsUtils
